@@ -142,7 +142,7 @@ public abstract class VmModelBehaviorBase<TModel extends UnitVmModel> {
             @Override
             public void eventRaised(Event<? extends EventArgs> ev, Object sender, EventArgs args) {
                 boolean ha = getModel().getIsHighlyAvailable().getEntity();
-                getModel().getLease().setIsChangeable(ha);
+                setVmLeasesAvailability();
                 if (!ha) {
                     getModel().getLease().setSelectedItem(null);
                 }
@@ -177,13 +177,24 @@ public abstract class VmModelBehaviorBase<TModel extends UnitVmModel> {
 
     private void setVmLeasesAvailability() {
         TModel model = getModel();
+        if (model.getSelectedCluster() == null) {
+            return;
+        }
+
         Version compVer = model.getSelectedCluster().getCompatibilityVersion();
         if (model.getCustomCompatibilityVersion().getSelectedItem() != null) {
             compVer = model.getCustomCompatibilityVersion().getSelectedItem();
         }
-        model.getLease().setIsChangeable(
-                AsyncDataProvider.getInstance().isVmLeasesFeatureSupported(compVer),
-                constants.vmLeasesSupported());
+        boolean vmLeasesSupported = AsyncDataProvider.getInstance().isVmLeasesFeatureSupported(compVer);
+        if (!vmLeasesSupported) {
+            model.getLease().setIsChangeable(false, constants.vmLeasesSupported());
+        }
+        else {
+            model.getLease().setIsChangeable(model.getIsHighlyAvailable().getEntity());
+            if (!model.getIsHighlyAvailable().getEntity()) {
+                model.getLease().setChangeProhibitionReason(constants.vmLeasesNotSupportedWithoutHA());
+            }
+        }
     }
 
     private void setRngAvailability() {
@@ -1302,10 +1313,7 @@ public abstract class VmModelBehaviorBase<TModel extends UnitVmModel> {
                             }
                         }
                         getModel().getLease().setItems(domains);
-                        if (!getModel().getLease().getIsChangable() || selectedStorageDomainId == null) {
-                            getModel().getLease().setSelectedItem(null);
-                        }
-                        else {
+                        if (selectedStorageDomainId != null) {
                             for (StorageDomain domain : domains) {
                                 if (domain != null && selectedStorageDomainId.equals(domain.getId())) {
                                     getModel().getLease().setSelectedItem(domain);
